@@ -9,7 +9,7 @@ use DBD::SQLite;
 with qw[Pcore::DBH];
 
 has mode => ( is => 'ro', isa => Enum [qw[R RW RWC]], default => 'RWC' );    # READONLY, READWRITE, READWRITE + CREATE
-has busy_timeout => ( is => 'ro', isa => Int, default => 1_000 * 5 );        # milliseconds, set to 0 to disable timeout, default - 5 seconds
+has busy_timeout => ( is => 'ro', isa => PositiveOrZeroInt, default => 1_000 * 3 );    # milliseconds, set to 0 to disable timeout, default - 3 seconds
 
 # SQLITE PRAGMAS
 has temp_store   => ( is => 'ro', isa => Enum [qw[FILE MEMORY]],                            default => 'MEMORY' );
